"""
This type stub file was generated by pyright.
"""

from __future__ import annotations

from functools import _lru_cache_wrapper
from types import FunctionType
from typing import Any

from jinja2 import Environment
from jinja2 import PackageLoader
from jinja2 import select_autoescape

from ozi_templates.filter import current_date
from ozi_templates.filter import next_minor
from ozi_templates.filter import sha256sum
from ozi_templates.filter import underscorify
from ozi_templates.filter import wheel_repr

"""ozi-templates module"""
__all__ = ('load_environment', )
FILTERS = ...
def load_environment(project: dict[str, str], _globals: dict[str, Any]) -> Environment:
    """Load the rendering environment for templates.

    :return: jinja2 rendering environment for OZI
    :rtype: Environment
    """
    ...

